@@ -305,12 +305,6 @@ plot.sivs <- function(x, type = c("frequency", "coef", "rfe"),
                 {
                     # if user have asked for specific strictness to be plotted over
                     if(!is.null(suggestion_strictness)){
-                        #>>==<v>==>> ToDo: Add a part to warn if all the aucs were NAs (I don't know why this should happen though! Julia might have this issue >>==<v>==>>
-                        if(all(sapply(x$rfe, function(x){ all(sapply(x, "[[", "auc")) }))){
-                            warning("")
-                        }
-                        #<<==<^>==<< ToDo: 1 <<==<^>==<<
-                        
                         # extract the median of AUCs from the sivs object
                         tmp.median.AUROCs <- sapply(x$rfe,
                                                 function(x){
